# ri.apiclient
API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.0.0
- Generator version: 7.5.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.robustintelligence.com](https://www.robustintelligence.com)

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import ri.apiclient
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import ri.apiclient
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import ri.apiclient
from ri.apiclient.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = ri.apiclient.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: rime-api-key
configuration.api_key['rime-api-key'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['rime-api-key'] = 'Bearer'


# Enter a context with an instance of the API client
with ri.apiclient.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = ri.apiclient.FirewallApi(api_client)
    firewall_instance_id_uuid = 'firewall_instance_id_uuid_example' # str | Unique object ID.

    try:
        # GetFirewallEffectiveConfig
        api_response = api_instance.effective_config(firewall_instance_id_uuid)
        print("The response of FirewallApi->effective_config:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling FirewallApi->effective_config: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*FirewallApi* | [**effective_config**](docs/FirewallApi.md#effective_config) | **GET** /v1-beta/firewall/{firewallInstanceId.uuid}/effective-config | GetFirewallEffectiveConfig
*FirewallApi* | [**validate**](docs/FirewallApi.md#validate) | **PUT** /v1-beta/firewall/{firewallInstanceId.uuid}/validate | Validate
*FirewallInstanceManagerApi* | [**create_instance**](docs/FirewallInstanceManagerApi.md#create_instance) | **POST** /v1-beta/firewall-instance | CreateFirewallInstance
*FirewallInstanceManagerApi* | [**delete_instance**](docs/FirewallInstanceManagerApi.md#delete_instance) | **DELETE** /v1-beta/firewall-instance/{firewallInstanceId.uuid} | DeleteFirewallInstance
*FirewallInstanceManagerApi* | [**get_instance**](docs/FirewallInstanceManagerApi.md#get_instance) | **GET** /v1-beta/firewall-instance/{firewallInstanceId.uuid} | GetFirewallInstance
*FirewallInstanceManagerApi* | [**list_instances**](docs/FirewallInstanceManagerApi.md#list_instances) | **GET** /v1-beta/firewall-instance | ListFirewallInstances
*FirewallInstanceManagerApi* | [**update_instance**](docs/FirewallInstanceManagerApi.md#update_instance) | **PATCH** /v1-beta/firewall-instance/{firewallInstance.firewallInstanceId.uuid} | UpdateFirewallInstance
*GenerativeModelTestingApi* | [**results**](docs/GenerativeModelTestingApi.md#results) | **GET** /v1-beta/generative/testing/{jobId.uuid} | GetGenerativeModelTestResults
*GenerativeModelTestingApi* | [**start_generative_test**](docs/GenerativeModelTestingApi.md#start_generative_test) | **POST** /v1-beta/generative/testing | StartGenerativeModelTest


## Documentation For Models

 - [AgentManagerUpgradeAgentRequest](docs/AgentManagerUpgradeAgentRequest.md)
 - [ApigenerativefirewallCreateFirewallInstanceRequest](docs/ApigenerativefirewallCreateFirewallInstanceRequest.md)
 - [ApigenerativefirewallCreateFirewallInstanceResponse](docs/ApigenerativefirewallCreateFirewallInstanceResponse.md)
 - [ApigenerativefirewallListFirewallInstancesResponse](docs/ApigenerativefirewallListFirewallInstancesResponse.md)
 - [ApigenerativefirewallStandardInfo](docs/ApigenerativefirewallStandardInfo.md)
 - [ArtifactIdentifierCategoryTestIdentifier](docs/ArtifactIdentifierCategoryTestIdentifier.md)
 - [ArtifactIdentifierSubsetTestMetricIdentifier](docs/ArtifactIdentifierSubsetTestMetricIdentifier.md)
 - [ArtifactIdentifierTestCaseMetricIdentifier](docs/ArtifactIdentifierTestCaseMetricIdentifier.md)
 - [CodeDetectionDetailsCodeSubstring](docs/CodeDetectionDetailsCodeSubstring.md)
 - [ConfigGenerationCategoryConfigGenerationServiceResponse](docs/ConfigGenerationCategoryConfigGenerationServiceResponse.md)
 - [ConfigGenerationProfilingConfigGenerationServiceResponse](docs/ConfigGenerationProfilingConfigGenerationServiceResponse.md)
 - [ConfigGenerationTestSuiteConfigGenerationServiceResponse](docs/ConfigGenerationTestSuiteConfigGenerationServiceResponse.md)
 - [CreateAgentRequestAWSConfig](docs/CreateAgentRequestAWSConfig.md)
 - [CreateAgentRequestAzureConfig](docs/CreateAgentRequestAzureConfig.md)
 - [CreateAgentRequestGCPConfig](docs/CreateAgentRequestGCPConfig.md)
 - [CreateFirewallRequestScheduledCTParameters](docs/CreateFirewallRequestScheduledCTParameters.md)
 - [CrossplanetaskCrossPlaneResponse](docs/CrossplanetaskCrossPlaneResponse.md)
 - [CustomImagePullSecret](docs/CustomImagePullSecret.md)
 - [CustomMetricCustomMetricMetadata](docs/CustomMetricCustomMetricMetadata.md)
 - [CustomermanagedkeyCustomerManagedKeyConfig](docs/CustomermanagedkeyCustomerManagedKeyConfig.md)
 - [CustomermanagedkeyKeyProvider](docs/CustomermanagedkeyKeyProvider.md)
 - [CustomermanagedkeyKeyStatus](docs/CustomermanagedkeyKeyStatus.md)
 - [DataCollectorRegisterDataStreamRequest](docs/DataCollectorRegisterDataStreamRequest.md)
 - [DataCollectorStoreDatapointsRequest](docs/DataCollectorStoreDatapointsRequest.md)
 - [DataCollectorStorePredictionsRequest](docs/DataCollectorStorePredictionsRequest.md)
 - [DataParamsFeatureIntersection](docs/DataParamsFeatureIntersection.md)
 - [DataParamsRankingInfo](docs/DataParamsRankingInfo.md)
 - [DataProfilingColumnTypeInfo](docs/DataProfilingColumnTypeInfo.md)
 - [DataProfilingFeatureRelationshipInfo](docs/DataProfilingFeatureRelationshipInfo.md)
 - [DatacollectorDatapoint](docs/DatacollectorDatapoint.md)
 - [DatacollectorDatapointRow](docs/DatacollectorDatapointRow.md)
 - [DatasetCTDatasetType](docs/DatasetCTDatasetType.md)
 - [DatasetCTInfo](docs/DatasetCTInfo.md)
 - [DatasetDataset](docs/DatasetDataset.md)
 - [DetectionDetectionEvent](docs/DetectionDetectionEvent.md)
 - [DetectionEventDetail](docs/DetectionEventDetail.md)
 - [DetectionEventType](docs/DetectionEventType.md)
 - [DetectionResolution](docs/DetectionResolution.md)
 - [DetectionSecurityEventDetails](docs/DetectionSecurityEventDetails.md)
 - [DifferenceFromTargetDifference](docs/DifferenceFromTargetDifference.md)
 - [DifferenceFromTargetTarget](docs/DifferenceFromTargetTarget.md)
 - [DigestConfigDigestFrequency](docs/DigestConfigDigestFrequency.md)
 - [FileSecurityReportDependency](docs/FileSecurityReportDependency.md)
 - [FilescanningPackageURL](docs/FilescanningPackageURL.md)
 - [FileserverCheckObjectExistsResponse](docs/FileserverCheckObjectExistsResponse.md)
 - [FileserverGetReadObjectPresignedLinkResponse](docs/FileserverGetReadObjectPresignedLinkResponse.md)
 - [FileserverGetUploadObjectPresignedLinkResponse](docs/FileserverGetUploadObjectPresignedLinkResponse.md)
 - [FileserverListObjectsResponse](docs/FileserverListObjectsResponse.md)
 - [FirewallFirewall](docs/FirewallFirewall.md)
 - [FirewallLatestRunInfo](docs/FirewallLatestRunInfo.md)
 - [FirewallScheduledCTInfo](docs/FirewallScheduledCTInfo.md)
 - [FirewallServiceUpdateFirewallRequest](docs/FirewallServiceUpdateFirewallRequest.md)
 - [FirewallServiceUpdateFirewallRequestFirewall](docs/FirewallServiceUpdateFirewallRequestFirewall.md)
 - [FirewallTestCategorySeverity](docs/FirewallTestCategorySeverity.md)
 - [FlaggedSubstringRequestBodyComponent](docs/FlaggedSubstringRequestBodyComponent.md)
 - [GenerativeTestingResultExample](docs/GenerativeTestingResultExample.md)
 - [GenerativefirewallCodeDetectionDetails](docs/GenerativefirewallCodeDetectionDetails.md)
 - [GenerativefirewallCodeDetectionRuleConfig](docs/GenerativefirewallCodeDetectionRuleConfig.md)
 - [GenerativefirewallCustomPiiEntity](docs/GenerativefirewallCustomPiiEntity.md)
 - [GenerativefirewallFirewallAction](docs/GenerativefirewallFirewallAction.md)
 - [GenerativefirewallFirewallInstanceDeploymentConfig](docs/GenerativefirewallFirewallInstanceDeploymentConfig.md)
 - [GenerativefirewallFirewallInstanceInfo](docs/GenerativefirewallFirewallInstanceInfo.md)
 - [GenerativefirewallFirewallInstanceStatus](docs/GenerativefirewallFirewallInstanceStatus.md)
 - [GenerativefirewallFirewallRuleConfig](docs/GenerativefirewallFirewallRuleConfig.md)
 - [GenerativefirewallFirewallRuleType](docs/GenerativefirewallFirewallRuleType.md)
 - [GenerativefirewallFirewallTokenizer](docs/GenerativefirewallFirewallTokenizer.md)
 - [GenerativefirewallFlaggedSubstring](docs/GenerativefirewallFlaggedSubstring.md)
 - [GenerativefirewallGetFirewallEffectiveConfigResponse](docs/GenerativefirewallGetFirewallEffectiveConfigResponse.md)
 - [GenerativefirewallGetFirewallInstanceResponse](docs/GenerativefirewallGetFirewallInstanceResponse.md)
 - [GenerativefirewallIndividualRulesConfig](docs/GenerativefirewallIndividualRulesConfig.md)
 - [GenerativefirewallLanguageDetectionDetails](docs/GenerativefirewallLanguageDetectionDetails.md)
 - [GenerativefirewallLanguageDetectionRuleConfig](docs/GenerativefirewallLanguageDetectionRuleConfig.md)
 - [GenerativefirewallOffTopicRuleConfig](docs/GenerativefirewallOffTopicRuleConfig.md)
 - [GenerativefirewallPiiDetectionDetails](docs/GenerativefirewallPiiDetectionDetails.md)
 - [GenerativefirewallPiiDetectionRuleConfig](docs/GenerativefirewallPiiDetectionRuleConfig.md)
 - [GenerativefirewallPiiEntityType](docs/GenerativefirewallPiiEntityType.md)
 - [GenerativefirewallPromptInjectionDetails](docs/GenerativefirewallPromptInjectionDetails.md)
 - [GenerativefirewallPromptInjectionRuleConfig](docs/GenerativefirewallPromptInjectionRuleConfig.md)
 - [GenerativefirewallRawModelPrediction](docs/GenerativefirewallRawModelPrediction.md)
 - [GenerativefirewallRuleOutput](docs/GenerativefirewallRuleOutput.md)
 - [GenerativefirewallRuleSensitivity](docs/GenerativefirewallRuleSensitivity.md)
 - [GenerativefirewallTokenCounterRuleConfig](docs/GenerativefirewallTokenCounterRuleConfig.md)
 - [GenerativefirewallToxicityDetectionDetails](docs/GenerativefirewallToxicityDetectionDetails.md)
 - [GenerativefirewallToxicityRuleConfig](docs/GenerativefirewallToxicityRuleConfig.md)
 - [GenerativefirewallUnknownExternalSourceRuleConfig](docs/GenerativefirewallUnknownExternalSourceRuleConfig.md)
 - [GenerativefirewallUpdateFirewallInstanceResponse](docs/GenerativefirewallUpdateFirewallInstanceResponse.md)
 - [GenerativefirewallValidateResponse](docs/GenerativefirewallValidateResponse.md)
 - [GenerativetestingGenerativeTestingResult](docs/GenerativetestingGenerativeTestingResult.md)
 - [GenerativetestingGenerativeTestingResultStandardInfo](docs/GenerativetestingGenerativeTestingResultStandardInfo.md)
 - [GenerativetestingGetGenerativeModelTestResultsResponse](docs/GenerativetestingGetGenerativeModelTestResultsResponse.md)
 - [GenerativetestingObjectiveSubCategory](docs/GenerativetestingObjectiveSubCategory.md)
 - [GenerativetestingStartGenerativeModelTestRequest](docs/GenerativetestingStartGenerativeModelTestRequest.md)
 - [GenerativetestingStartGenerativeModelTestResponse](docs/GenerativetestingStartGenerativeModelTestResponse.md)
 - [GenerativetestingThreat](docs/GenerativetestingThreat.md)
 - [GooglerpcStatus](docs/GooglerpcStatus.md)
 - [ImageReferenceReferenceType](docs/ImageReferenceReferenceType.md)
 - [IntegrationIntegrationLevel](docs/IntegrationIntegrationLevel.md)
 - [IntegrationIntegrationSchema](docs/IntegrationIntegrationSchema.md)
 - [IntegrationIntegrationType](docs/IntegrationIntegrationType.md)
 - [IntegrationServiceConfigureIntegrationRequest](docs/IntegrationServiceConfigureIntegrationRequest.md)
 - [IntegrationServiceUpdateIntegrationRequest](docs/IntegrationServiceUpdateIntegrationRequest.md)
 - [IntegrationServiceUpdateIntegrationRequestIntegration](docs/IntegrationServiceUpdateIntegrationRequestIntegration.md)
 - [IntegrationVariableSensitivity](docs/IntegrationVariableSensitivity.md)
 - [JobDataContinuousIncrementalTest](docs/JobDataContinuousIncrementalTest.md)
 - [JobDataScan](docs/JobDataScan.md)
 - [JobDataStressTest](docs/JobDataStressTest.md)
 - [LanguageDetectionDetailsLanguageSubstring](docs/LanguageDetectionDetailsLanguageSubstring.md)
 - [LibgenerativeSeverity](docs/LibgenerativeSeverity.md)
 - [ListAPITokensRequestListAPITokensQuery](docs/ListAPITokensRequestListAPITokensQuery.md)
 - [ListAgentsRequestListAgentsQuery](docs/ListAgentsRequestListAgentsQuery.md)
 - [ListDatasetsRequestDatasetsQuery](docs/ListDatasetsRequestDatasetsQuery.md)
 - [ListFileScanResultsRequestFileScanQuery](docs/ListFileScanResultsRequestFileScanQuery.md)
 - [ListFirewallInstancesRequestListFirewallInstancesQuery](docs/ListFirewallInstancesRequestListFirewallInstancesQuery.md)
 - [ListImagesRequestPipLibraryFilter](docs/ListImagesRequestPipLibraryFilter.md)
 - [ListMetricIdentifiersResponseAggregatedMetric](docs/ListMetricIdentifiersResponseAggregatedMetric.md)
 - [ListMetricIdentifiersResponseFeatureMetricWithoutSubsets](docs/ListMetricIdentifiersResponseFeatureMetricWithoutSubsets.md)
 - [ListMetricIdentifiersResponseFeatureMetrics](docs/ListMetricIdentifiersResponseFeatureMetrics.md)
 - [ListMetricIdentifiersResponseSubsetMetric](docs/ListMetricIdentifiersResponseSubsetMetric.md)
 - [ListMetricIdentifiersResponseSubsetMetrics](docs/ListMetricIdentifiersResponseSubsetMetrics.md)
 - [ListMonitorsRequestFilter](docs/ListMonitorsRequestFilter.md)
 - [ListNotificationsRequestListNotificationsQuery](docs/ListNotificationsRequestListNotificationsQuery.md)
 - [ListPredictionSetsRequestPredictionQuery](docs/ListPredictionSetsRequestPredictionQuery.md)
 - [ListSummaryTestsRequestListSummaryTestsQuery](docs/ListSummaryTestsRequestListSummaryTestsQuery.md)
 - [ListTestCasesRequestListTestCasesQuery](docs/ListTestCasesRequestListTestCasesQuery.md)
 - [ManagedImagePackageRequirement](docs/ManagedImagePackageRequirement.md)
 - [ManagedImagePipLibrary](docs/ManagedImagePipLibrary.md)
 - [ManagedImagePipRequirement](docs/ManagedImagePipRequirement.md)
 - [ManagedImageRoleType](docs/ManagedImageRoleType.md)
 - [ModelCardServiceUpdateModelCardRequest](docs/ModelCardServiceUpdateModelCardRequest.md)
 - [ModelCardServiceUpdateModelCardRequestModelCard](docs/ModelCardServiceUpdateModelCardRequestModelCard.md)
 - [ModelModel](docs/ModelModel.md)
 - [ModelTestingStartContinuousTestRequest](docs/ModelTestingStartContinuousTestRequest.md)
 - [ModelTestingStartStressTestRequest](docs/ModelTestingStartStressTestRequest.md)
 - [MonitorAggregation](docs/MonitorAggregation.md)
 - [MonitorAggregationType](docs/MonitorAggregationType.md)
 - [MonitorArtifactIdentifier](docs/MonitorArtifactIdentifier.md)
 - [MonitorDifferenceFromTarget](docs/MonitorDifferenceFromTarget.md)
 - [MonitorExcludedTransforms](docs/MonitorExcludedTransforms.md)
 - [MonitorMetricDegradationConfig](docs/MonitorMetricDegradationConfig.md)
 - [MonitorMonitor](docs/MonitorMonitor.md)
 - [MonitorMonitorType](docs/MonitorMonitorType.md)
 - [MonitorServiceCreateCustomMonitorRequest](docs/MonitorServiceCreateCustomMonitorRequest.md)
 - [MonitorServiceUpdateMonitorRequest](docs/MonitorServiceUpdateMonitorRequest.md)
 - [MonitorServiceUpdateMonitorRequestMonitor](docs/MonitorServiceUpdateMonitorRequestMonitor.md)
 - [MonitorThreshold](docs/MonitorThreshold.md)
 - [MonitorThresholdType](docs/MonitorThresholdType.md)
 - [MonitorTransform](docs/MonitorTransform.md)
 - [MonitoringConfigAlertLevel](docs/MonitoringConfigAlertLevel.md)
 - [NotificationDigestConfig](docs/NotificationDigestConfig.md)
 - [NotificationMonitoringConfig](docs/NotificationMonitoringConfig.md)
 - [NotificationNotification](docs/NotificationNotification.md)
 - [NotificationNotificationType](docs/NotificationNotificationType.md)
 - [NotificationObjectType](docs/NotificationObjectType.md)
 - [NotificationSettingUpdateNotificationRequest](docs/NotificationSettingUpdateNotificationRequest.md)
 - [NotificationSettingUpdateNotificationRequestNotification](docs/NotificationSettingUpdateNotificationRequestNotification.md)
 - [NotificationWebhookConfig](docs/NotificationWebhookConfig.md)
 - [PiiDetectionDetailsFlaggedEntity](docs/PiiDetectionDetailsFlaggedEntity.md)
 - [ProjectActivateScheduleForProjectResponse](docs/ProjectActivateScheduleForProjectResponse.md)
 - [ProjectCreateProjectRequest](docs/ProjectCreateProjectRequest.md)
 - [ProjectCreateProjectResponse](docs/ProjectCreateProjectResponse.md)
 - [ProjectGetProjectResponse](docs/ProjectGetProjectResponse.md)
 - [ProjectGetProjectURLResponse](docs/ProjectGetProjectURLResponse.md)
 - [ProjectGetWorkspaceRolesForProjectResponse](docs/ProjectGetWorkspaceRolesForProjectResponse.md)
 - [ProjectListProjectsRequestQuery](docs/ProjectListProjectsRequestQuery.md)
 - [ProjectListProjectsResponse](docs/ProjectListProjectsResponse.md)
 - [ProjectListUsersOfProjectResponse](docs/ProjectListUsersOfProjectResponse.md)
 - [ProjectOwnerDetails](docs/ProjectOwnerDetails.md)
 - [ProjectProject](docs/ProjectProject.md)
 - [ProjectProjectStatus](docs/ProjectProjectStatus.md)
 - [ProjectProjectWithDetails](docs/ProjectProjectWithDetails.md)
 - [ProjectScheduleInfo](docs/ProjectScheduleInfo.md)
 - [ProjectServiceActivateScheduleForProjectRequest](docs/ProjectServiceActivateScheduleForProjectRequest.md)
 - [ProjectServiceAddUsersToProjectRequest](docs/ProjectServiceAddUsersToProjectRequest.md)
 - [ProjectServiceUpdateProjectRequest](docs/ProjectServiceUpdateProjectRequest.md)
 - [ProjectServiceUpdateUserOfProjectRequest](docs/ProjectServiceUpdateUserOfProjectRequest.md)
 - [ProjectServiceUpdateUserOfProjectRequestUser](docs/ProjectServiceUpdateUserOfProjectRequestUser.md)
 - [ProjectServiceUpdateWorkspaceRolesForProjectRequest](docs/ProjectServiceUpdateWorkspaceRolesForProjectRequest.md)
 - [ProjectUpdateProjectResponse](docs/ProjectUpdateProjectResponse.md)
 - [ProjectUpdateWorkspaceRolesForProjectResponse](docs/ProjectUpdateWorkspaceRolesForProjectResponse.md)
 - [ProtobufAny](docs/ProtobufAny.md)
 - [ProtobufNullValue](docs/ProtobufNullValue.md)
 - [RawModelPredictionTextClassificationPred](docs/RawModelPredictionTextClassificationPred.md)
 - [RegistryConnectionInfo](docs/RegistryConnectionInfo.md)
 - [RegistryDataCollectorInfo](docs/RegistryDataCollectorInfo.md)
 - [RegistryDataFileInfo](docs/RegistryDataFileInfo.md)
 - [RegistryDataInfo](docs/RegistryDataInfo.md)
 - [RegistryDataLoadingInfo](docs/RegistryDataLoadingInfo.md)
 - [RegistryDataParams](docs/RegistryDataParams.md)
 - [RegistryDataType](docs/RegistryDataType.md)
 - [RegistryDatabricksInfo](docs/RegistryDatabricksInfo.md)
 - [RegistryHuggingFaceDataInfo](docs/RegistryHuggingFaceDataInfo.md)
 - [RegistryHuggingFaceModelInfo](docs/RegistryHuggingFaceModelInfo.md)
 - [RegistryMetadata](docs/RegistryMetadata.md)
 - [RegistryModelPathInfo](docs/RegistryModelPathInfo.md)
 - [RegistryPredInfo](docs/RegistryPredInfo.md)
 - [RegistryPredictionParams](docs/RegistryPredictionParams.md)
 - [RegistryServiceRegisterDatasetRequest](docs/RegistryServiceRegisterDatasetRequest.md)
 - [RegistryServiceRegisterModelRequest](docs/RegistryServiceRegisterModelRequest.md)
 - [RegistryServiceRegisterPredictionSetRequest](docs/RegistryServiceRegisterPredictionSetRequest.md)
 - [RegistryValidityStatus](docs/RegistryValidityStatus.md)
 - [RegistrypredictionPrediction](docs/RegistrypredictionPrediction.md)
 - [ResultsReaderRenameTestRunRequest](docs/ResultsReaderRenameTestRunRequest.md)
 - [RimeAPITokenInfo](docs/RimeAPITokenInfo.md)
 - [RimeActorRole](docs/RimeActorRole.md)
 - [RimeAgent](docs/RimeAgent.md)
 - [RimeAgentDesiredState](docs/RimeAgentDesiredState.md)
 - [RimeAgentStatus](docs/RimeAgentStatus.md)
 - [RimeAgentType](docs/RimeAgentType.md)
 - [RimeAttackObjective](docs/RimeAttackObjective.md)
 - [RimeAttackTechnique](docs/RimeAttackTechnique.md)
 - [RimeCategoryMetric](docs/RimeCategoryMetric.md)
 - [RimeCategoryTestResult](docs/RimeCategoryTestResult.md)
 - [RimeConfigureIntegrationRequestIntegrationVariable](docs/RimeConfigureIntegrationRequestIntegrationVariable.md)
 - [RimeConfigureIntegrationResponse](docs/RimeConfigureIntegrationResponse.md)
 - [RimeContinuousTestJobProgress](docs/RimeContinuousTestJobProgress.md)
 - [RimeContinuousTestRunProgress](docs/RimeContinuousTestRunProgress.md)
 - [RimeCreateAPITokenRequest](docs/RimeCreateAPITokenRequest.md)
 - [RimeCreateAPITokenResponse](docs/RimeCreateAPITokenResponse.md)
 - [RimeCreateAgentRequest](docs/RimeCreateAgentRequest.md)
 - [RimeCreateAgentResponse](docs/RimeCreateAgentResponse.md)
 - [RimeCreateCustomMonitorResponse](docs/RimeCreateCustomMonitorResponse.md)
 - [RimeCreateCustomerManagedKeyRequest](docs/RimeCreateCustomerManagedKeyRequest.md)
 - [RimeCreateCustomerManagedKeyResponse](docs/RimeCreateCustomerManagedKeyResponse.md)
 - [RimeCreateFirewallAgentRequest](docs/RimeCreateFirewallAgentRequest.md)
 - [RimeCreateFirewallAgentResponse](docs/RimeCreateFirewallAgentResponse.md)
 - [RimeCreateFirewallRequest](docs/RimeCreateFirewallRequest.md)
 - [RimeCreateFirewallResponse](docs/RimeCreateFirewallResponse.md)
 - [RimeCreateImageRequest](docs/RimeCreateImageRequest.md)
 - [RimeCreateImageResponse](docs/RimeCreateImageResponse.md)
 - [RimeCreateIntegrationRequest](docs/RimeCreateIntegrationRequest.md)
 - [RimeCreateIntegrationResponse](docs/RimeCreateIntegrationResponse.md)
 - [RimeCreateModelCardRequest](docs/RimeCreateModelCardRequest.md)
 - [RimeCreateModelCardResponse](docs/RimeCreateModelCardResponse.md)
 - [RimeCreateNotificationRequest](docs/RimeCreateNotificationRequest.md)
 - [RimeCreateNotificationResponse](docs/RimeCreateNotificationResponse.md)
 - [RimeCreateScheduleRequest](docs/RimeCreateScheduleRequest.md)
 - [RimeCreateScheduleResponse](docs/RimeCreateScheduleResponse.md)
 - [RimeCreateUserRequest](docs/RimeCreateUserRequest.md)
 - [RimeCreateUserResponse](docs/RimeCreateUserResponse.md)
 - [RimeCreateWorkspaceRequest](docs/RimeCreateWorkspaceRequest.md)
 - [RimeCreateWorkspaceResponse](docs/RimeCreateWorkspaceResponse.md)
 - [RimeDeleteModelCardResponse](docs/RimeDeleteModelCardResponse.md)
 - [RimeDetailedUpgradeStatus](docs/RimeDetailedUpgradeStatus.md)
 - [RimeFailingRow](docs/RimeFailingRow.md)
 - [RimeFailingRowsResult](docs/RimeFailingRowsResult.md)
 - [RimeFeatureType](docs/RimeFeatureType.md)
 - [RimeFileScanResult](docs/RimeFileScanResult.md)
 - [RimeFileSecurityReport](docs/RimeFileSecurityReport.md)
 - [RimeFloatList](docs/RimeFloatList.md)
 - [RimeGenerativeModelTestProgress](docs/RimeGenerativeModelTestProgress.md)
 - [RimeGetAgentResponse](docs/RimeGetAgentResponse.md)
 - [RimeGetCustomerManagedKeyResponse](docs/RimeGetCustomerManagedKeyResponse.md)
 - [RimeGetDatapointsResponse](docs/RimeGetDatapointsResponse.md)
 - [RimeGetDatasetFileUploadURLRequest](docs/RimeGetDatasetFileUploadURLRequest.md)
 - [RimeGetDatasetFileUploadURLResponse](docs/RimeGetDatasetFileUploadURLResponse.md)
 - [RimeGetDatasetResponse](docs/RimeGetDatasetResponse.md)
 - [RimeGetFeatureFlagJwtResponse](docs/RimeGetFeatureFlagJwtResponse.md)
 - [RimeGetFileScanResultResponse](docs/RimeGetFileScanResultResponse.md)
 - [RimeGetFirewallResponse](docs/RimeGetFirewallResponse.md)
 - [RimeGetImageResponse](docs/RimeGetImageResponse.md)
 - [RimeGetIntegrationResponse](docs/RimeGetIntegrationResponse.md)
 - [RimeGetJobResponse](docs/RimeGetJobResponse.md)
 - [RimeGetKeyStatusResponse](docs/RimeGetKeyStatusResponse.md)
 - [RimeGetLimitStatusResponse](docs/RimeGetLimitStatusResponse.md)
 - [RimeGetModelCardResponse](docs/RimeGetModelCardResponse.md)
 - [RimeGetModelDirectoryUploadURLsRequest](docs/RimeGetModelDirectoryUploadURLsRequest.md)
 - [RimeGetModelDirectoryUploadURLsResponse](docs/RimeGetModelDirectoryUploadURLsResponse.md)
 - [RimeGetModelResponse](docs/RimeGetModelResponse.md)
 - [RimeGetModelSecurityReportResponse](docs/RimeGetModelSecurityReportResponse.md)
 - [RimeGetMonitorResultResponse](docs/RimeGetMonitorResultResponse.md)
 - [RimeGetPredictionSetResponse](docs/RimeGetPredictionSetResponse.md)
 - [RimeGetPredictionsResponse](docs/RimeGetPredictionsResponse.md)
 - [RimeGetProjectIDResponse](docs/RimeGetProjectIDResponse.md)
 - [RimeGetRIMEInfoResponse](docs/RimeGetRIMEInfoResponse.md)
 - [RimeGetScheduleResponse](docs/RimeGetScheduleResponse.md)
 - [RimeGetTestRunIDResponse](docs/RimeGetTestRunIDResponse.md)
 - [RimeGetURLResponse](docs/RimeGetURLResponse.md)
 - [RimeGetUpgradeForAgentResponse](docs/RimeGetUpgradeForAgentResponse.md)
 - [RimeGetUserResponse](docs/RimeGetUserResponse.md)
 - [RimeGetValidateDatasetTaskStatusResponse](docs/RimeGetValidateDatasetTaskStatusResponse.md)
 - [RimeGetValidateModelTaskStatusResponse](docs/RimeGetValidateModelTaskStatusResponse.md)
 - [RimeGetValidatePredictionsTaskStatusResponse](docs/RimeGetValidatePredictionsTaskStatusResponse.md)
 - [RimeGetWorkspaceResponse](docs/RimeGetWorkspaceResponse.md)
 - [RimeImageReference](docs/RimeImageReference.md)
 - [RimeIntList](docs/RimeIntList.md)
 - [RimeIntegrationInfo](docs/RimeIntegrationInfo.md)
 - [RimeJobData](docs/RimeJobData.md)
 - [RimeJobDataGenerativeModelTest](docs/RimeJobDataGenerativeModelTest.md)
 - [RimeJobMetadata](docs/RimeJobMetadata.md)
 - [RimeJobType](docs/RimeJobType.md)
 - [RimeJobView](docs/RimeJobView.md)
 - [RimeLanguage](docs/RimeLanguage.md)
 - [RimeLicenseFeature](docs/RimeLicenseFeature.md)
 - [RimeLicenseLimit](docs/RimeLicenseLimit.md)
 - [RimeLimitStatus](docs/RimeLimitStatus.md)
 - [RimeLimitStatusStatus](docs/RimeLimitStatusStatus.md)
 - [RimeListAPITokensResponse](docs/RimeListAPITokensResponse.md)
 - [RimeListAgentsResponse](docs/RimeListAgentsResponse.md)
 - [RimeListCurrentUserRolesResponse](docs/RimeListCurrentUserRolesResponse.md)
 - [RimeListDatasetsResponse](docs/RimeListDatasetsResponse.md)
 - [RimeListDetectionEventsRequestQuery](docs/RimeListDetectionEventsRequestQuery.md)
 - [RimeListDetectionEventsResponse](docs/RimeListDetectionEventsResponse.md)
 - [RimeListEnabledFeaturesResponse](docs/RimeListEnabledFeaturesResponse.md)
 - [RimeListFileScanResultsResponse](docs/RimeListFileScanResultsResponse.md)
 - [RimeListFirewallInstancesResponse](docs/RimeListFirewallInstancesResponse.md)
 - [RimeListGAITestJobResponse](docs/RimeListGAITestJobResponse.md)
 - [RimeListGAITestJobsRequestQuery](docs/RimeListGAITestJobsRequestQuery.md)
 - [RimeListImagesRequest](docs/RimeListImagesRequest.md)
 - [RimeListImagesResponse](docs/RimeListImagesResponse.md)
 - [RimeListJobsForProjectRequestQuery](docs/RimeListJobsForProjectRequestQuery.md)
 - [RimeListJobsForProjectResponse](docs/RimeListJobsForProjectResponse.md)
 - [RimeListMetricIdentifiersResponse](docs/RimeListMetricIdentifiersResponse.md)
 - [RimeListModelCardsResponse](docs/RimeListModelCardsResponse.md)
 - [RimeListModelsResponse](docs/RimeListModelsResponse.md)
 - [RimeListMonitorsResponse](docs/RimeListMonitorsResponse.md)
 - [RimeListNotificationsResponse](docs/RimeListNotificationsResponse.md)
 - [RimeListPredictionSetsResponse](docs/RimeListPredictionSetsResponse.md)
 - [RimeListProjectTagsInWorkspaceResponse](docs/RimeListProjectTagsInWorkspaceResponse.md)
 - [RimeListUploadedFileURLsResponse](docs/RimeListUploadedFileURLsResponse.md)
 - [RimeListUsersOfWorkspaceResponse](docs/RimeListUsersOfWorkspaceResponse.md)
 - [RimeListUsersResponse](docs/RimeListUsersResponse.md)
 - [RimeListWorkspaceIntegrationsResponse](docs/RimeListWorkspaceIntegrationsResponse.md)
 - [RimeListWorkspacesResponse](docs/RimeListWorkspacesResponse.md)
 - [RimeLongDescriptionTab](docs/RimeLongDescriptionTab.md)
 - [RimeManagedImage](docs/RimeManagedImage.md)
 - [RimeManagedImagePackageType](docs/RimeManagedImagePackageType.md)
 - [RimeManagedImageStatus](docs/RimeManagedImageStatus.md)
 - [RimeModelCard](docs/RimeModelCard.md)
 - [RimeModelTask](docs/RimeModelTask.md)
 - [RimeModelWithOwnerDetails](docs/RimeModelWithOwnerDetails.md)
 - [RimeMonitorDataPoint](docs/RimeMonitorDataPoint.md)
 - [RimeNamedDouble](docs/RimeNamedDouble.md)
 - [RimeOrder](docs/RimeOrder.md)
 - [RimeParentRoleSubjectRolePair](docs/RimeParentRoleSubjectRolePair.md)
 - [RimeRIPlan](docs/RimeRIPlan.md)
 - [RimeRegisterDataStreamResponse](docs/RimeRegisterDataStreamResponse.md)
 - [RimeRegisterDatasetResponse](docs/RimeRegisterDatasetResponse.md)
 - [RimeRegisterModelResponse](docs/RimeRegisterModelResponse.md)
 - [RimeRegisterPredictionSetResponse](docs/RimeRegisterPredictionSetResponse.md)
 - [RimeRepoMetadata](docs/RimeRepoMetadata.md)
 - [RimeRepoMetadataLicense](docs/RimeRepoMetadataLicense.md)
 - [RimeRepoMetadataReputation](docs/RimeRepoMetadataReputation.md)
 - [RimeSafeURL](docs/RimeSafeURL.md)
 - [RimeSearchSpec](docs/RimeSearchSpec.md)
 - [RimeSeverity](docs/RimeSeverity.md)
 - [RimeSeverityCounts](docs/RimeSeverityCounts.md)
 - [RimeSortSpec](docs/RimeSortSpec.md)
 - [RimeStartContinuousTestResponse](docs/RimeStartContinuousTestResponse.md)
 - [RimeStartFileScanRequest](docs/RimeStartFileScanRequest.md)
 - [RimeStartFileScanResponse](docs/RimeStartFileScanResponse.md)
 - [RimeStartStressTestResponse](docs/RimeStartStressTestResponse.md)
 - [RimeStartValidateDatasetTaskResponse](docs/RimeStartValidateDatasetTaskResponse.md)
 - [RimeStartValidateModelTaskResponse](docs/RimeStartValidateModelTaskResponse.md)
 - [RimeStartValidatePredictionsTaskResponse](docs/RimeStartValidatePredictionsTaskResponse.md)
 - [RimeStoreDatapointsResponse](docs/RimeStoreDatapointsResponse.md)
 - [RimeStorePredictionsRequestPrediction](docs/RimeStorePredictionsRequestPrediction.md)
 - [RimeStrList](docs/RimeStrList.md)
 - [RimeStressTestJobProgress](docs/RimeStressTestJobProgress.md)
 - [RimeSubjectType](docs/RimeSubjectType.md)
 - [RimeSuggestion](docs/RimeSuggestion.md)
 - [RimeSyncImageTagResponse](docs/RimeSyncImageTagResponse.md)
 - [RimeTableColumn](docs/RimeTableColumn.md)
 - [RimeTableColumnType](docs/RimeTableColumnType.md)
 - [RimeTestCaseMonitorInfo](docs/RimeTestCaseMonitorInfo.md)
 - [RimeTestCaseStatus](docs/RimeTestCaseStatus.md)
 - [RimeTestMetric](docs/RimeTestMetric.md)
 - [RimeTestMetricCategory](docs/RimeTestMetricCategory.md)
 - [RimeTestRunProgress](docs/RimeTestRunProgress.md)
 - [RimeTestTaskStatus](docs/RimeTestTaskStatus.md)
 - [RimeTestType](docs/RimeTestType.md)
 - [RimeTimeInterval](docs/RimeTimeInterval.md)
 - [RimeTokenType](docs/RimeTokenType.md)
 - [RimeToxicityThreatCategory](docs/RimeToxicityThreatCategory.md)
 - [RimeUUID](docs/RimeUUID.md)
 - [RimeUpdateFirewallResponse](docs/RimeUpdateFirewallResponse.md)
 - [RimeUpdateIntegrationResponse](docs/RimeUpdateIntegrationResponse.md)
 - [RimeUpdateModelCardResponse](docs/RimeUpdateModelCardResponse.md)
 - [RimeUpdateMonitorResponse](docs/RimeUpdateMonitorResponse.md)
 - [RimeUpdateNotificationResponse](docs/RimeUpdateNotificationResponse.md)
 - [RimeUpdateScheduleResponse](docs/RimeUpdateScheduleResponse.md)
 - [RimeUpgradeStatus](docs/RimeUpgradeStatus.md)
 - [RimeUserDetailWithRole](docs/RimeUserDetailWithRole.md)
 - [RimeUserRole](docs/RimeUserRole.md)
 - [RimeUserWithRole](docs/RimeUserWithRole.md)
 - [RimeUserWriteMask](docs/RimeUserWriteMask.md)
 - [RimeWorkspace](docs/RimeWorkspace.md)
 - [RimeWorkspaceWriteMask](docs/RimeWorkspaceWriteMask.md)
 - [RischemaintegrationIntegration](docs/RischemaintegrationIntegration.md)
 - [RiskscoreRiskCategoryType](docs/RiskscoreRiskCategoryType.md)
 - [RiskscoreRiskScore](docs/RiskscoreRiskScore.md)
 - [RuleEvaluationMetadataYaraInfo](docs/RuleEvaluationMetadataYaraInfo.md)
 - [RuleOutputRuleEvaluationMetadata](docs/RuleOutputRuleEvaluationMetadata.md)
 - [RuleOutputRuleEvaluationMetadataModelInfo](docs/RuleOutputRuleEvaluationMetadataModelInfo.md)
 - [RuntimeinfoCustomImage](docs/RuntimeinfoCustomImage.md)
 - [RuntimeinfoCustomImageType](docs/RuntimeinfoCustomImageType.md)
 - [RuntimeinfoResourceRequest](docs/RuntimeinfoResourceRequest.md)
 - [RuntimeinfoRunTimeInfo](docs/RuntimeinfoRunTimeInfo.md)
 - [ScheduleSchedule](docs/ScheduleSchedule.md)
 - [ScheduleServiceUpdateScheduleRequest](docs/ScheduleServiceUpdateScheduleRequest.md)
 - [SchemadatacollectorPrediction](docs/SchemadatacollectorPrediction.md)
 - [SchemafilescanningFileScanResult](docs/SchemafilescanningFileScanResult.md)
 - [SchemafilescanningFileSecurityReport](docs/SchemafilescanningFileSecurityReport.md)
 - [SchemafilescanningPackageType](docs/SchemafilescanningPackageType.md)
 - [SchemafilescanningRepoMetadata](docs/SchemafilescanningRepoMetadata.md)
 - [SchemafilescanningRepoMetadataLicense](docs/SchemafilescanningRepoMetadataLicense.md)
 - [SchemafilescanningRepoMetadataReputation](docs/SchemafilescanningRepoMetadataReputation.md)
 - [SchemaintegrationIntegrationVariable](docs/SchemaintegrationIntegrationVariable.md)
 - [SchemamonitorConfig](docs/SchemamonitorConfig.md)
 - [SchemanotificationConfig](docs/SchemanotificationConfig.md)
 - [SchemaregistryModelInfo](docs/SchemaregistryModelInfo.md)
 - [SecurityEventDetailsFlaggedDatapoint](docs/SecurityEventDetailsFlaggedDatapoint.md)
 - [SecurityEventDetailsSecurityEventType](docs/SecurityEventDetailsSecurityEventType.md)
 - [StatedbArchivedJobLogs](docs/StatedbArchivedJobLogs.md)
 - [StatedbJobStatus](docs/StatedbJobStatus.md)
 - [StreamResultOfRimeGetDatapointsResponse](docs/StreamResultOfRimeGetDatapointsResponse.md)
 - [StreamResultOfRimeGetPredictionsResponse](docs/StreamResultOfRimeGetPredictionsResponse.md)
 - [TestRunMetricsCategorySummaryMetric](docs/TestRunMetricsCategorySummaryMetric.md)
 - [TestRunMetricsModelPerfMetric](docs/TestRunMetricsModelPerfMetric.md)
 - [TestRunProgressTestBatchProgress](docs/TestRunProgressTestBatchProgress.md)
 - [TestrunAnnotatedTestConfig](docs/TestrunAnnotatedTestConfig.md)
 - [TestrunCustomMetric](docs/TestrunCustomMetric.md)
 - [TestrunDataProfiling](docs/TestrunDataProfiling.md)
 - [TestrunModelProfiling](docs/TestrunModelProfiling.md)
 - [TestrunProfilingConfig](docs/TestrunProfilingConfig.md)
 - [TestrunRefEvalDatasets](docs/TestrunRefEvalDatasets.md)
 - [TestrunTestCategoryType](docs/TestrunTestCategoryType.md)
 - [TestrunTestRunConfig](docs/TestrunTestRunConfig.md)
 - [TestrunTestRunIncrementalConfig](docs/TestrunTestRunIncrementalConfig.md)
 - [TestrunTestSensitivity](docs/TestrunTestSensitivity.md)
 - [TestrunTestSuiteConfig](docs/TestrunTestSuiteConfig.md)
 - [TestrunresultGetBatchResultResponse](docs/TestrunresultGetBatchResultResponse.md)
 - [TestrunresultGetCategoryResultsResponse](docs/TestrunresultGetCategoryResultsResponse.md)
 - [TestrunresultGetFeatureResultResponse](docs/TestrunresultGetFeatureResultResponse.md)
 - [TestrunresultGetTestConfigResponse](docs/TestrunresultGetTestConfigResponse.md)
 - [TestrunresultGetTestRunResponse](docs/TestrunresultGetTestRunResponse.md)
 - [TestrunresultListBatchResultsResponse](docs/TestrunresultListBatchResultsResponse.md)
 - [TestrunresultListFeatureResultsResponse](docs/TestrunresultListFeatureResultsResponse.md)
 - [TestrunresultListMonitorCategoriesResponse](docs/TestrunresultListMonitorCategoriesResponse.md)
 - [TestrunresultListSummaryTestsResponse](docs/TestrunresultListSummaryTestsResponse.md)
 - [TestrunresultListTestCasesResponse](docs/TestrunresultListTestCasesResponse.md)
 - [TestrunresultListTestRunsRequestQuery](docs/TestrunresultListTestRunsRequestQuery.md)
 - [TestrunresultListTestRunsResponse](docs/TestrunresultListTestRunsResponse.md)
 - [TestrunresultListValidationCategoriesResponse](docs/TestrunresultListValidationCategoriesResponse.md)
 - [TestrunresultRenameTestRunResponse](docs/TestrunresultRenameTestRunResponse.md)
 - [TestrunresultResultSummaryCounts](docs/TestrunresultResultSummaryCounts.md)
 - [TestrunresultTestBatchResult](docs/TestrunresultTestBatchResult.md)
 - [TestrunresultTestBatchResultDisplay](docs/TestrunresultTestBatchResultDisplay.md)
 - [TestrunresultTestCase](docs/TestrunresultTestCase.md)
 - [TestrunresultTestCaseDisplay](docs/TestrunresultTestCaseDisplay.md)
 - [TestrunresultTestFeatureResult](docs/TestrunresultTestFeatureResult.md)
 - [TestrunresultTestFeatureResultDisplay](docs/TestrunresultTestFeatureResultDisplay.md)
 - [TestrunresultTestRunDetail](docs/TestrunresultTestRunDetail.md)
 - [TestrunresultTestRunMetrics](docs/TestrunresultTestRunMetrics.md)
 - [UpdateInstanceRequest](docs/UpdateInstanceRequest.md)
 - [UserFavoriteProjects](docs/UserFavoriteProjects.md)
 - [UserPrivateInfo](docs/UserPrivateInfo.md)
 - [UserResetPasswordRequest](docs/UserResetPasswordRequest.md)
 - [UserRole](docs/UserRole.md)
 - [UserUpdateUserRequest](docs/UserUpdateUserRequest.md)
 - [UserUpdateUserRequestUser](docs/UserUpdateUserRequestUser.md)
 - [UserUserDetail](docs/UserUserDetail.md)
 - [ValidateRequest](docs/ValidateRequest.md)
 - [ValidateResponseProcessedRequest](docs/ValidateResponseProcessedRequest.md)
 - [ValidateResponseProductMetadata](docs/ValidateResponseProductMetadata.md)
 - [ValidationValidateDatasetResponse](docs/ValidationValidateDatasetResponse.md)
 - [ValidationValidateModelResponse](docs/ValidationValidateModelResponse.md)
 - [ValidationValidatePredictionsResponse](docs/ValidationValidatePredictionsResponse.md)
 - [WorkspaceServiceAddUsersToWorkspaceRequest](docs/WorkspaceServiceAddUsersToWorkspaceRequest.md)
 - [WorkspaceServiceUpdateUserOfWorkspaceRequest](docs/WorkspaceServiceUpdateUserOfWorkspaceRequest.md)
 - [WorkspaceServiceUpdateWorkspaceRequest](docs/WorkspaceServiceUpdateWorkspaceRequest.md)
 - [WorkspaceServiceUpdateWorkspaceRequestWorkspace](docs/WorkspaceServiceUpdateWorkspaceRequestWorkspace.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="rime-api-key"></a>
### rime-api-key

- **Type**: API key
- **API key parameter name**: rime-api-key
- **Location**: HTTP header


## Author

dev@robustintelligence.com
